/// <reference types="jest" />
declare global {
    namespace jest {
        interface Matchers<R> {
            /**
             * Ensures that the actual value is within some percent error of the expected value.
             *
             * @param expected - the expected value
             * @param percent - the maximum percent error to tolerate
             */
            toBeWithinPercent(expected: number, percent: number): R;
        }
    }
}
/**
 * Checks whether the actual value is within the given percent error of the
 * expected value.
 *
 * The percent error check is inclusive.
 */
export default function toBeWithinPercent(this: jest.MatcherUtils, actual: number, expected: number, percent: number): {
    message: () => string;
    pass: boolean;
};
